@@ -1,4 +1,3 @@
-
 context("Fidelity of estimators for time-varying treatment")
 
 tmp <- sim_t4
@@ -8,6 +7,7 @@ time_varying <- list(c("L_1"), c("L_2"), c("L_3"), c("L_4"))
 for (i in a) {
   tmp[[i]] <- factor(tmp[[i]], levels = 0:5, ordered = TRUE)
 }
+
 d <- function(data, trt) {
   out <- list()
   a <- data[[trt]]
@@ -23,20 +23,11 @@ d <- function(data, trt) {
 
 truth <- 0.305
 
-# estimators
-sub <- sw(lmtp_sub(tmp, a, "Y", time_vary = time_varying, shift = d,
-                   folds = 2, .SL_folds = 2))
+sub <- sw(lmtp_sub(tmp, a, "Y", time_vary = time_varying, shift = d, folds = 1))
+ipw <- sw(lmtp_ipw(tmp, a, "Y", time_vary = time_varying, shift = d, intervention_type = "mtp", folds = 1))
+tmle <- sw(lmtp_tmle(tmp, a, "Y", time_vary = time_varying, shift = d, intervention_type = "mtp", folds = 1))
+sdr <- sw(lmtp_sdr(tmp, a, "Y", time_vary = time_varying, shift = d, intervention_type = "mtp", folds = 1))
 
-ipw <- sw(lmtp_ipw(tmp, a, "Y", time_vary = time_varying, shift = d,
-                   intervention_type = "mtp", folds = 2, .SL_folds = 2))
-
-tmle <- sw(lmtp_tmle(tmp, a, "Y", time_vary = time_varying, shift = d,
-                     intervention_type = "mtp", folds = 2, .SL_folds = 2))
-
-sdr <- sw(lmtp_sdr(tmp, a, "Y", time_vary = time_varying, shift = d,
-                   intervention_type = "mtp", folds = 2, .SL_folds = 2))
-
-# tests
 test_that("time varying treatment fidelity, t = 4", {
   expect_equal(truth, sub$theta, tolerance = 0.025)
   expect_equal(truth, ipw$theta, tolerance = 0.05)
